@@ -27,22 +27,25 @@
 ##' @param clipdst,clipdstsql,clipdstlayer,clipdstwhere,wrapdateline
 ##'     See \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
 ##'     documentation}.
-##' @param datelineoffset,simplify,segmentize,makevalid See
+##' @param datelineoffset,simplify,segmentize,makevalid,addfields See
 ##'     See \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
 ##'     documentation}.
-##' @param fieldTypeToString,mapFieldType,unsetFieldWidth
+##' @param unsetFid,emptyStrAsNull,relaxedFieldNameMatch,forceNullable
+##'     See See \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
+##'     documentation}.
+##' @param unsetDefault,fieldTypeToString,unsetFieldWidth,mapFieldType
 ##'     See \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
 ##'     documentation}.
-##' @param splitlistfields,maxsubfields,explodecollections,zfield,gcp
-##'     See \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
-##'     documentation}.
-##' @param order,tps,fieldmap,addfields,relaxedFieldNameMatch
-##'     See \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
-##'     documentation}.
-##' @param forceNullable,unsetDefault,unsetFid,emptyStrAsNull,nomd See
+##' @param fieldmap,splitlistfields,maxsubfields See
 ##'     \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
 ##'     documentation}.
-##' @param mo,noNativeData See
+##' @param resolveDomains,explodecollections,zfield,gcp,order,tps See
+##'     \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
+##'     documentation}.
+##' @param s_coord_epoch,t_coord_epoch,a_coord_epoch See
+##'     \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
+##'     documentation}.
+##' @param nomd,mo,noNativeData See
 ##'     \href{https://gdal.org/programs/ogr2ogr.html}{ogr2ogr
 ##'     documentation}.
 ##' @param dryrun Logical (default \code{FALSE}). If \code{TRUE},
@@ -51,7 +54,7 @@
 ##'     equivalent output.
 ##' @name ogr2ogr
 ##' @rdname ogr2ogr
-##' @return None. Called instead for its side effect.
+##' @return Silently returns path to \code{dst_datasource_name}.
 ##' @export
 ##' @author Joshua O'Brien
 ##' @examples
@@ -88,11 +91,12 @@ ogr2ogr <-
              clipsrc, clipsrcsql, clipsrclayer, clipsrcwhere, clipdst,
              clipdstsql, clipdstlayer, clipdstwhere, wrapdateline,
              datelineoffset, simplify, segmentize, makevalid,
-             fieldTypeToString, mapFieldType, unsetFieldWidth,
-             splitlistfields, maxsubfields, explodecollections,
-             zfield, gcp, order, tps, fieldmap, addfields,
-             relaxedFieldNameMatch, forceNullable, unsetDefault,
-             unsetFid, emptyStrAsNull, nomd, mo, noNativeData,
+             fieldTypeToString, unsetFieldWidth, mapFieldType,
+             fieldmap, splitlistfields, maxsubfields, resolveDomains,
+             explodecollections, zfield, gcp, order, tps,
+             s_coord_epoch, t_coord_epoch, a_coord_epoch, addfields,
+             unsetFid, emptyStrAsNull, relaxedFieldNameMatch,
+             forceNullable, unsetDefault, nomd, mo, noNativeData,
              dryrun = FALSE)
 {
     ## Unlike `as.list(match.call())`, forces eval of arguments
