@@ -10,17 +10,19 @@
 ##     ls(asNamespace("gdalUtilities")[[".gdUtilsEnv"]]))
 getFormalsTable <- function(fun) {
     switch(fun,
-           gdal_rasterize = get("args_gdal_rasterize", envir=.gdUtilsEnv),
-           gdal_translate = get("args_gdal_translate", envir=.gdUtilsEnv),
-           gdalwarp       = get("args_gdalwarp", envir=.gdUtilsEnv),
-           gdaldem        = get("args_gdaldem", envir=.gdUtilsEnv),
-           ## gdal_contour   = get("args_gdal_contour", envir=.gdUtilsEnv),
-           gdalinfo       = get("args_gdalinfo", envir=.gdUtilsEnv),
-           ## gdaltindex     = get("args_gdaltindex", envir=.gdUtilsEnv),
-           ogr2ogr        = get("args_ogr2ogr", envir=.gdUtilsEnv),
-           nearblack      = get("args_nearblack", envir=.gdUtilsEnv),
-           gdal_grid      = get("args_gdal_grid", envir=.gdUtilsEnv),
-           gdalbuildvrt   = get("args_gdalbuildvrt", envir=.gdUtilsEnv))
+           gdal_rasterize    = get("args_gdal_rasterize", envir=.gdUtilsEnv),
+           gdal_translate    = get("args_gdal_translate", envir=.gdUtilsEnv),
+           gdalwarp          = get("args_gdalwarp", envir=.gdUtilsEnv),
+           gdaldem           = get("args_gdaldem", envir=.gdUtilsEnv),
+           ## gdal_contour      = get("args_gdal_contour", envir=.gdUtilsEnv),
+           gdalinfo          = get("args_gdalinfo", envir=.gdUtilsEnv),
+           ## gdaltindex        = get("args_gdaltindex", envir=.gdUtilsEnv),
+           ogr2ogr           = get("args_ogr2ogr", envir=.gdUtilsEnv),
+           nearblack         = get("args_nearblack", envir=.gdUtilsEnv),
+           gdal_grid         = get("args_gdal_grid", envir=.gdUtilsEnv),
+           gdalbuildvrt      = get("args_gdalbuildvrt", envir=.gdUtilsEnv),
+           gdalmdiminfo      = get("args_gdalmdiminfo", envir=.gdUtilsEnv),
+           gdalmdimtranslate = get("args_gdalmdimtranslate", envir=.gdUtilsEnv))
 }
 
 
@@ -80,10 +82,11 @@ projwin_srs,   -projwin_srs,   1,    FALSE
 epo,           -epo,           0,    FALSE
 eco,           -eco,           0,    FALSE
 a_srs,         -a_srs,         1,    FALSE
-a_scale,       -a_scale,       1,    FALSE
-a_offset,      -a_offset,      1,    FALSE
+a_coord_epoch, -a_coord_epoch, 1,    FALSE
 a_ullr,        -a_ullr,        4,    FALSE
 a_nodata,      -a_nodata,      1,    FALSE
+a_scale,       -a_scale,       1,    FALSE
+a_offset,      -a_offset,      1,    FALSE
 colorinterp,   -colorinterp,   1,    FALSE
 mo,            -mo,            1,    TRUE
 co,            -co,            1,    TRUE
@@ -108,7 +111,10 @@ s_srs,           -s_srs,           1,    FALSE
 t_srs,           -t_srs,           1,    FALSE
 ct,              -ct,              1,    FALSE
 to,              -to,              1,    FALSE
-novshiftgrid,    -novshiftgrid,    1,    FALSE
+vshift,          -vshift,          0,    FALSE
+novshift,        -novshift,        0,    FALSE
+s_coord_epoch,   -s_coord_epoch,   1,    FALSE
+t_coord_epoch,   -t_coord_epoch,   1,    FALSE
 order,           -order,           1,    FALSE
 tps,             -tps,             0,    FALSE
 rpc,             -rpc,             0,    FALSE
@@ -241,11 +247,15 @@ mapFieldType,          -mapFieldType,         1,    FALSE
 fieldmap,              -fieldmap,             1,    FALSE
 splitlistfields,       -splitlistfields,      0,    FALSE
 maxsubfields,          -maxsubfields,         1,    FALSE
+resolveDomains,        -resolveDomains,       0,    FALSE
 explodecollections,    -explodecollections,   0,    FALSE
 zfield,                -zfield,               1,    FALSE
 gcp,                   -gcp,                  4,    TRUE
 order,                 -order,                1,    FALSE
 tps,                   -tps,                  0,    FALSE
+s_coord_epoch,         -s_coord_epoch,        1,    FALSE
+t_coord_epoch,         -t_coord_epoch,        1,    FALSE
+a_coord_epoch,         -a_coord_epoch,        1,    FALSE
 nomd,                  -nomd,                 0,    FALSE
 mo,                    -mo,                   1,    TRUE
 noNativeData,          -noNativeData,         0,    FALSE",
@@ -272,8 +282,8 @@ listmdd,       -listmdd,      0,    FALSE
 mdd,           -mdd,          1,    FALSE
 wkt_format,    -wkt_format,   1,    FALSE
 sd,            -sd,           1,    FALSE
-oo,            -oo,           1,    FALSE,
-IF,            -if,           1,    FALSE",
+oo,            -oo,           1,    TRUE,
+IF,            -if,           1,    TRUE",
 stringsAsFactors = FALSE, strip.white = TRUE,
 colClasses = c("character", "character", "numeric", "logical"))
 
@@ -336,7 +346,7 @@ te,                           -te,                          4,    FALSE
 tr,                           -tr,                          2,    FALSE
 tap,                          -tap,                         0,    FALSE
 separate,                     -separate,                    0,    FALSE
-b,                            -b,                           1,    FALSE
+b,                            -b,                           1,    TRUE
 sd,                           -sd,                          1,    FALSE
 allow_projection_difference,  -allow_projection_difference, 0,    FALSE
 q,                            -q,                           0,    FALSE
@@ -349,12 +359,44 @@ ignore_srcmaskband,           -ignore_srcmaskband,          0,    FALSE
 a_srs,                        -a_srs,                       1,    FALSE
 r,                            -r,                           1,    FALSE
 oo,                           -oo,                          1,    TRUE
-in0put_file_list,              -input_file_list,             1,    FALSE
+input_file_list,              -input_file_list,             1,    FALSE
+strict,                       -strict,                      0,    FALSE
+non_strict,                   -non_strict,                  0,    FALSE
 overwrite,                    -overwrite,                   0,    FALSE",
 stringsAsFactors = FALSE, strip.white = TRUE,
 colClasses = c("character", "character", "numeric", "logical"))
 
 
+.gdUtilsEnv[["args_gdalmdiminfo"]] <- read.csv(text = "
+arg,           flag,          narg, repeatable
+datasetname,   ,              1,    FALSE
+oo,            -oo,           1,    TRUE
+arrayoption,   -arrayoption,  1,    TRUE
+detailed,      -detailed,     0,    FALSE
+nopretty,      -nopretty,     0,    FALSE
+array,         -array,        1,    FALSE
+limit,         -limit,        1,    FALSE
+stats,         -stats,        0,    FALSE
+IF,            -if,           1,    TRUE",
+stringsAsFactors = FALSE, strip.white = TRUE,
+colClasses = c("character", "character", "numeric", "logical"))
+
+
+.gdUtilsEnv[["args_gdalmdimtranslate"]] <- read.csv(text = "
+arg,           flag,          narg, repeatable
+src_filename,  ,              1,    FALSE
+dst_filename,  ,              1,    FALSE
+co,            -co,           1,    TRUE
+IF,            -if,           1,    TRUE
+of,            -of,           1,    FALSE
+array,         -array,        1,    TRUE
+group,         -group,        1,    TRUE
+subset,        -subset,       1,    TRUE
+scaleaxes,     -scaleaxes,    1,    TRUE
+oo,            -oo,           1,    TRUE",
+stringsAsFactors = FALSE, strip.white = TRUE,
+colClasses = c("character", "character", "numeric", "logical"))
+
 
 
 
